OC.L10N.register(
    "notes",
    {
    "Error" : "错误",
    "New note" : "新建笔记",
    "Notes" : "笔记",
    "Distraction-free notes and writing" : "无干扰的笔记和写作",
    "Deleted {title}" : "已删除 {title}",
    "Deleted {number} notes" : "已删除 {number} 条笔记",
    "Undo Delete" : "撤销删除",
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
    "Settings" : "设置",
    "Folder to store your notes" : "保存您的笔记的文件夹",
    "path to notes" : "笔记的路径",
    "File extension for new notes" : "新笔记的文件扩展名",
    "All notes" : "所有笔记",
    "Categories" : "分类",
    "No search result for “{search}” in {category}" : "在 {category} 中没有关于 “{search}”的搜索结果",
    "No search result for “{search}”" : "没有关于“{search}”的搜索结果",
    "Loading …" : "正在加载…",
    "Search result for “{search}” in {category}" : "在{category}中搜索 “{search}”的结果",
    "Search result for “{search}”" : "搜索 “{search}”的结果",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "This week" : "本周",
    "Last week" : "上周",
    "This month" : "本月",
    "Last month" : "上月",
    "Rename" : "重命名",
    "Delete note" : "删除笔记",
    "Remove from favorites" : "从收藏夹移除",
    "Add to favorites" : "添加到收藏夹",
    "Error during preparing note for deletion." : "准备删除笔记时出错。",
    "Empty note" : "空笔记",
    "Write …" : "编写 ...",
    "Details" : "详细信息",
    "Edit" : "编辑",
    "Preview" : "预览",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Save failed. Click to retry." : "保存失败。点击以重试。",
    "Set category" : "设置分类",
    "Category" : "分类",
    "Uncategorized" : "未分类",
    "Click here to save manually" : "点击这里以手动保存",
    "Saving failed!" : "保存失败！",
    "Last modified: {date}" : "上一次更改：{date}",
    "Note has unsaved changes" : "笔记有未保存的更改",
    "Subcategory" : "子类别",
    "_%n word_::_%n words_" : ["%n 个字"],
    "Write down your thoughts without any distractions." : "心无旁骛地写下您的想法。",
    "Use Markdown markups to style your text." : "使用Markdown标注来格式化您的文本。",
    "Organize your notes in categories." : "在分类中组织您的笔记。",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "在您的手机中安装此应用以随时随地访问您的笔记。",
    "Android app" : "安卓应用",
    "iOS app" : "iOS 应用",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "在应用导航栏中点击“{newnote}”开始做笔记",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "您可以创建子类别，在父类别和子类别之间使用 “/” 作为分隔符，例如 “{parent}/{sub}”。",
    "See JavaScript console and server log for details." : "有关详情请参见 JavaScript 控制台和服务器日志。",
    "Updating settings has failed." : "更新设置失败。",
    "Fetching notes has failed." : "获取笔记失败。",
    "Fetching note {id} has failed." : "获取笔记 {id} 失败。",
    "Creating new note has failed." : "创建新笔记失败。",
    "Undo delete has failed for note {title}." : "笔记 {title} 的撤消删除失败。",
    "Deleting note {id} has failed." : "删除笔记 {id} 失败。",
    "Toggling favorite for note {id} has failed." : "将笔记 {id} 设为收藏失败。",
    "Updating the note's category has failed. Is the target directory writable?" : "无法更新存储笔记的文件夹。请检查目标文件夹是否可写。",
    "Updating the category for note {id} has failed." : "更新笔记 {id} 的分类失败。",
    "Development Mode" : "开发模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "笔记应用似乎是从一个开发来源安装的。请改从官方<a href=\"%1$s\">Nextcloud应用商店</a>来安装它。如果您想自己笔记应用，请参考<a href=\"%2$s\">开发者指南</a>。"
},
"nplurals=1; plural=0;");
